module Cachix.Client.Command
  ( Cache.use,
    Cache.remove,
    Config.authtoken,
    Config.generateKeypair,
    Doctor.daemonDoctor,
    Doctor.doctor,
    Import.import',
    Pin.pin,
    Push.push,
    Watch.watchExec,
    Watch.watchExecDaemon,
    Watch.watchExecStore,
    Watch.watchStore,
  )
where

import Cachix.Client.Command.Cache qualified as Cache
import Cachix.Client.Command.Config qualified as Config
import Cachix.Client.Command.Doctor qualified as Doctor
import Cachix.Client.Command.Import qualified as Import
import Cachix.Client.Command.Pin qualified as Pin
import Cachix.Client.Command.Push qualified as Push
import Cachix.Client.Command.Watch qualified as Watch
